Function open_append

pub fn open_append<P: AsRef<Path> + Debug>(path: P) -> Result<File>
Open a file for writing in append mode, without truncating it if it exists, but creating it if it doesn’t exist. E.g. for writing logs.